==> geolocator-1.7.0.tar.gz: android/src/main/java/com/baseflow/flutter/plugin/geolocator/tasks/LastKnownLocationUsingLocationServicesTask.java <==
package com.baseflow.flutter.plugin.geolocator.tasks;

import android.location.Location;
import android.support.annotation.NonNull;

import com.baseflow.flutter.plugin.geolocator.data.LocationMapper;
import com.google.android.gms.location.FusedLocationProviderClient;
import com.google.android.gms.location.LocationServices;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;

import java.util.Map;

class LastKnownLocationUsingLocationServicesTask extends LocationUsingLocationServicesTask {
    private final FusedLocationProviderClient mFusedLocationProviderClient;

    LastKnownLocationUsingLocationServicesTask(TaskContext taskContext) {
        super(taskContext);

        mFusedLocationProviderClient = LocationServices.getFusedLocationProviderClient(taskContext.getAndroidContext());
    }

    @Override
    public void startTask() {
        mFusedLocationProviderClient.getLastLocation()
                .addOnSuccessListener(new OnSuccessListener<Location>() {
                    @Override
                    public void onSuccess(Location location) {
                        Map<String, Object> locationMap = location != null
                                ? LocationMapper.toHashMap(location)
                                : null;

                        getTaskContext().getResult().success(locationMap);

                        stopTask();
                    }
                })
                .addOnFailureListener(new OnFailureListener() {
                    @Override
                    public void onFailure(@NonNull Exception e) {
                        getTaskContext().getResult().error(
                                e.getMessage(),
                                e.getLocalizedMessage(),
                                null);

                        stopTask();
                    }
                });
    }
}

==> geolocator-2.0.0.tar.gz: android/src/main/java/com/baseflow/flutter/plugin/geolocator/tasks/LastKnownLocationUsingLocationServicesTask.java <==
package com.baseflow.flutter.plugin.geolocator.tasks;

import android.location.Location;
import android.support.annotation.NonNull;

import com.baseflow.flutter.plugin.geolocator.data.PositionMapper;
import com.google.android.gms.location.FusedLocationProviderClient;
import com.google.android.gms.location.LocationServices;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;

import java.util.Map;

class LastKnownLocationUsingLocationServicesTask extends LocationUsingLocationServicesTask {
    private final FusedLocationProviderClient mFusedLocationProviderClient;

    LastKnownLocationUsingLocationServicesTask(TaskContext taskContext) {
        super(taskContext);

        mFusedLocationProviderClient = LocationServices.getFusedLocationProviderClient(taskContext.getAndroidContext());
    }

    @Override
    public void startTask() {
        mFusedLocationProviderClient.getLastLocation()
                .addOnSuccessListener(new OnSuccessListener<Location>() {
                    @Override
                    public void onSuccess(Location location) {
                        Map<String, Object> locationMap = location != null
                                ? PositionMapper.toHashMap(location)
                                : null;

                        getTaskContext().getResult().success(locationMap);

                        stopTask();
                    }
                })
                .addOnFailureListener(new OnFailureListener() {
                    @Override
                    public void onFailure(@NonNull Exception e) {
                        getTaskContext().getResult().error(
                                e.getMessage(),
                                e.getLocalizedMessage(),
                                null);

                        stopTask();
                    }
                });
    }
}
